@@ -9,14 +9,15 @@ import 'package:analyzer/dart/ast/ast.dart';
 import 'package:analyzer/dart/element/element.dart';
 import 'package:analyzer/src/summary/format.dart';
 import 'package:analyzer/src/summary/idl.dart';
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
 import '../../abstract_single_unit.dart';
 
 main() {
-  groupSep = ' | ';
-  defineReflectiveTests(PackageIndexAssemblerTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(PackageIndexAssemblerTest);
+  });
 }
 
 class ExpectedLocation {
