@@ -7,15 +7,15 @@ library test.services.refactoring.rename_class_member;
 import 'package:analysis_server/plugin/protocol/protocol.dart';
 import 'package:analysis_server/src/services/correction/status.dart';
 import 'package:analyzer/src/generated/source.dart';
+import 'package:test/test.dart';
 import 'package:test_reflective_loader/test_reflective_loader.dart';
-import 'package:unittest/unittest.dart';
 
-import '../../utils.dart';
 import 'abstract_rename.dart';
 
 main() {
-  initializeTestEnvironment();
-  defineReflectiveTests(RenameClassMemberTest);
+  defineReflectiveSuite(() {
+    defineReflectiveTests(RenameClassMemberTest);
+  });
 }
 
 @reflectiveTest
