@@ -4,9 +4,8 @@
 
 library test.services.src.search.all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../../utils.dart';
 import 'hierarchy_test.dart' as hierarchy_test;
 import 'search_engine_test.dart' as search_engine_test;
 
@@ -14,9 +13,8 @@ import 'search_engine_test.dart' as search_engine_test;
  * Utility for manually running all tests.
  */
 main() {
-  initializeTestEnvironment();
-  group('search', () {
+  defineReflectiveSuite(() {
     hierarchy_test.main();
     search_engine_test.main();
-  });
+  }, name: 'search');
 }
