@@ -4,7 +4,8 @@
 
 library test.services;
 
-import '../utils.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
+
 import 'completion/test_all.dart' as completion_all;
 import 'correction/test_all.dart' as correction_all;
 import 'dependencies/test_all.dart' as dependencies_all;
@@ -15,12 +16,13 @@ import 'search/test_all.dart' as search_all;
 
 /// Utility for manually running all tests.
 main() {
-  initializeTestEnvironment();
-  completion_all.main();
-  correction_all.main();
-  dependencies_all.main();
-  index_all.main();
-  linter_all.main();
-  refactoring_all.main();
-  search_all.main();
+  defineReflectiveSuite(() {
+    completion_all.main();
+    correction_all.main();
+    dependencies_all.main();
+    index_all.main();
+    linter_all.main();
+    refactoring_all.main();
+    search_all.main();
+  });
 }
