@@ -4,17 +4,15 @@
 
 library analyzer.test.generated.test_all;
 
-import 'package:unittest/unittest.dart';
+import 'package:test_reflective_loader/test_reflective_loader.dart';
 
-import '../utils.dart';
 import 'ast/test_all.dart' as ast;
 import 'element/test_all.dart' as element;
 
 /// Utility for manually running all tests.
 main() {
-  initializeTestEnvironment();
-  group('dart tests', () {
+  defineReflectiveSuite(() {
     ast.main();
     element.main();
-  });
+  }, name: 'dart');
 }
